"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandLineModule = void 0;
const app_1 = require("@api-typed/app");
const logger_1 = require("@api-typed/logger");
const commander_1 = require("commander");
const CommandRegistry_1 = __importDefault(require("./CommandRegistry"));
const CommandRunner_1 = __importDefault(require("./CommandRunner"));
class CommandLineModule extends app_1.AbstractModule {
    constructor() {
        super(...arguments);
        this.name = 'command';
        this.registry = CommandRegistry_1.default;
        this.runner = CommandRunner_1.default;
    }
    loadConfig(config) {
        const verbose = process.argv.includes('-vvv') || process.argv.includes('--verbose');
        config.loadFromObject({
            log_level: verbose
                ? logger_1.LogLevel.debug
                : process.env.LOG_LEVEL_CLI || logger_1.LogLevel.info,
        });
    }
    init(app) {
        this.app = app;
        if (app.getRunMode() === 'command') {
            return this;
        }
    }
    async start() {
        this.runner.useContainer(this.app.container);
        this.runner.setAppBanner(this.app.config.get('appName'), this.app.config.get('version'));
        this.runner.onExit(async (exitCode) => {
            await this.app.stop(exitCode);
        });
        this.runner.program.addOption(new commander_1.Option('-vvv, --verbose', 'set log level to debug regardless of config setting'));
        this.app.loadFromModules('loadCommands');
        await this.runner.run(process.argv);
    }
    async stop(exitCode = 0) {
        process.exit(exitCode);
    }
    addCommand(command) {
        this.registry.addCommand(command);
    }
}
exports.CommandLineModule = CommandLineModule;
//# sourceMappingURL=CommandLineModule.js.map